==> flink-runtime-1.14.3-sources.jar: org/apache/flink/runtime/rest/handler/async/TriggerResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.handler.async;

import org.apache.flink.runtime.rest.messages.ResponseBody;
import org.apache.flink.runtime.rest.messages.TriggerId;
import org.apache.flink.util.Preconditions;

import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonCreator;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonProperty;

/** Response to the triggering of an asynchronous operation. */
public class TriggerResponse implements ResponseBody {
    private static final String FIELD_NAME_REQUEST_ID = "request-id";

    @JsonProperty(FIELD_NAME_REQUEST_ID)
    private final TriggerId triggerId;

    @JsonCreator
    public TriggerResponse(@JsonProperty(FIELD_NAME_REQUEST_ID) TriggerId triggerId) {
        this.triggerId = Preconditions.checkNotNull(triggerId);
    }

    public TriggerId getTriggerId() {
        return triggerId;
    }
}

==> flink-runtime_2.11-1.10.2-sources.jar: org/apache/flink/runtime/rest/handler/async/TriggerResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.rest.handler.async;

import org.apache.flink.runtime.rest.messages.ResponseBody;
import org.apache.flink.runtime.rest.messages.TriggerId;
import org.apache.flink.util.Preconditions;

import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonCreator;
import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Response to the triggering of an asynchronous operation.
 */
public class TriggerResponse implements ResponseBody {
	private static final String FIELD_NAME_REQUEST_ID = "request-id";

	@JsonProperty(FIELD_NAME_REQUEST_ID)
	private final TriggerId triggerId;

	@JsonCreator
	public TriggerResponse(
			@JsonProperty(FIELD_NAME_REQUEST_ID) TriggerId triggerId) {
		this.triggerId = Preconditions.checkNotNull(triggerId);
	}

	public TriggerId getTriggerId() {
		return triggerId;
	}
}
